(* ::Package:: *)

(* mdg.m *)

(* Developing Version *)

(* Created by Rolf Sulanke *)

(* Started April 13, 2010*)

(* This package contains tools applied in notebooks about 
M\[ODoubleDot]bius differential geometry, mainly in three or two dimensions. *)

(* Hint:s. 

1. Be sure, that besides of this package also the packages neuvec.m, euvec.m, and 
vectorcalc.m, and eudiffgeo.m are contained in the working path $Path.

2. After importing this package define the numbers
dim (= dimension) and ind (=index) of the pseudo-euclidean vector space. They  are defined as constants within the Global context of the notebook!!! These 
numbers may be changed later in the notebook, if wanted. If they are defined before importing the notewbook they will be fixed for all the modules introduce in the packages!*)

(* Free software: Feel free to apply, distribute or change my packages and
notebooks. Please, cite the source and notice the
changes, or new concepts,  which you introduced.*)



(* WARNINGS. *)




BeginPackage["mdg`",{"vectorcalc`", "euvec`", "neuvec`", "eudiffgeo`"}] 
   
(* The usages *)

iob::usage = 
  "iob[i,d:dim], 0<=i<=d -1, is the isotropic-orthonormal standard \
basis of the pseudo-Euclidean vector space of dimension dim and index \
1, numbered from 0 to dim -1.";

io::usage = 
  "io[] is the matrix of the scalar product of index 1 in the \
dim-dimensional pseudo-Euclidean vector space with respect to \
isotropic orthonormal coordinates.";

transio::usage = 
  "transio[] is the matrix transforming the pseudo-orthonormal \
coordinates of a pseudo-Euclidean vector space of dimension dim and \
index 1 to the corresponding isotropic orthonormal coordinates.";

transoi::usage = 
  "transoi[] is the matrix transforming the  isotropic-orthonormal \
coordinates of a pseudo-Euclidean vector space of dimension dim and \
index 1 to the corresponding pseudo-orthonormal basis.";

sphmap::usage = "sphmap[ulist]maps the isotropic vector u onto the 
corresponding point of the unit hypersphere. Warning: The index 
must equal 1, and the result is valid for isotropic vectors in 
pseudo-orthogonal coordinates only!";

mfre3D::usage = "mfre3D[k,h] is the matrix of the Moebius Frenet formulae 
with curvatures k, h in the three-dimensional Moebius space.";

dimm = Global`dim; 

indd = Global`ind; 

Begin["`Private`"]
(* The dimension dim, and the index ind  must be set within the Global Context. For the concepts in this package the *)

iob[i_] := Module[{d = dimm},
  If[i >= 1 && i < d - 1, Return[stb[i + 1]]];
  If[i == 0, Return[(stb[1] - stb[d])/Sqrt[2]]];
  If[i == d - 1, Return[(stb[1] + stb[d])/Sqrt[2]]];
  Print["Incorrect argument!"]; Return[]];

io[] := Table[pssp[iob[i], iob[j]], {i, 0, dimm - 1}, {j, 0, dimm - 1}]

transio[] := Table[iob[i], {i, 0, dimm - 1}];

transoi[ ] := Transpose[transio[]];

sphmap[u_List ]:=Take[u/u[[1]],-Length[u]+1]


mfre3D[k_, h_] := {{0, k, 1, 0, 0}, {1, 0, 0, 0, k}, {0, 0, 0, -h, 1}, {0,
    0, h, 0, 0}, {0, 1, 0, 0, 0}};

End[]	
Protect["io", "iob", "transio", "transoi", "mfre3D"]
EndPackage[]

